==> zio-aws-iam_3-5.17.121.2-sources.jar: zio/aws/iam/model/ListAttachedGroupPoliciesResponse.scala <==
package zio.aws.iam.model
import zio.aws.iam.model.primitives.{ResponseMarkerType, BooleanType}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListAttachedGroupPoliciesResponse(
    attachedPolicies: Option[Iterable[zio.aws.iam.model.AttachedPolicy]] = None,
    isTruncated: Option[BooleanType] = None,
    marker: Option[ResponseMarkerType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iam.model.ListAttachedGroupPoliciesResponse = {
    import ListAttachedGroupPoliciesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iam.model.ListAttachedGroupPoliciesResponse
      .builder()
      .optionallyWith(
        attachedPolicies.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.attachedPolicies)
      .optionallyWith(
        isTruncated.map(value => BooleanType.unwrap(value): java.lang.Boolean)
      )(_.isTruncated)
      .optionallyWith(
        marker.map(value => ResponseMarkerType.unwrap(value): java.lang.String)
      )(_.marker)
      .build()
  }
  def asReadOnly: zio.aws.iam.model.ListAttachedGroupPoliciesResponse.ReadOnly =
    zio.aws.iam.model.ListAttachedGroupPoliciesResponse.wrap(buildAwsValue())
}
object ListAttachedGroupPoliciesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iam.model.ListAttachedGroupPoliciesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iam.model.ListAttachedGroupPoliciesResponse =
      zio.aws.iam.model.ListAttachedGroupPoliciesResponse(
        attachedPolicies.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        isTruncated.map(value => value),
        marker.map(value => value)
      )
    def attachedPolicies
        : Option[List[zio.aws.iam.model.AttachedPolicy.ReadOnly]]
    def isTruncated: Option[BooleanType]
    def marker: Option[ResponseMarkerType]
    def getAttachedPolicies
        : ZIO[Any, AwsError, List[zio.aws.iam.model.AttachedPolicy.ReadOnly]] =
      AwsError.unwrapOptionField("attachedPolicies", attachedPolicies)
    def getIsTruncated: ZIO[Any, AwsError, BooleanType] =
      AwsError.unwrapOptionField("isTruncated", isTruncated)
    def getMarker: ZIO[Any, AwsError, ResponseMarkerType] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iam.model.ListAttachedGroupPoliciesResponse
  ) extends zio.aws.iam.model.ListAttachedGroupPoliciesResponse.ReadOnly {
    override val attachedPolicies
        : Option[List[zio.aws.iam.model.AttachedPolicy.ReadOnly]] = scala
      .Option(impl.attachedPolicies())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.iam.model.AttachedPolicy.wrap(item)
        }.toList
      )
    override val isTruncated: Option[BooleanType] = scala
      .Option(impl.isTruncated())
      .map(value => zio.aws.iam.model.primitives.BooleanType(value))
    override val marker: Option[ResponseMarkerType] = scala
      .Option(impl.marker())
      .map(value => zio.aws.iam.model.primitives.ResponseMarkerType(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iam.model.ListAttachedGroupPoliciesResponse
  ): zio.aws.iam.model.ListAttachedGroupPoliciesResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-iam_3-6.20.103.2-sources.jar: zio/aws/iam/model/ListAttachedGroupPoliciesResponse.scala <==
package zio.aws.iam.model
import zio.aws.iam.model.primitives.{ResponseMarkerType, BooleanType}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ListAttachedGroupPoliciesResponse(
    attachedPolicies: Optional[Iterable[zio.aws.iam.model.AttachedPolicy]] =
      Optional.Absent,
    isTruncated: Optional[BooleanType] = Optional.Absent,
    marker: Optional[ResponseMarkerType] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iam.model.ListAttachedGroupPoliciesResponse = {
    import ListAttachedGroupPoliciesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iam.model.ListAttachedGroupPoliciesResponse
      .builder()
      .optionallyWith(
        attachedPolicies.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.attachedPolicies)
      .optionallyWith(
        isTruncated.map(value => BooleanType.unwrap(value): java.lang.Boolean)
      )(_.isTruncated)
      .optionallyWith(
        marker.map(value => ResponseMarkerType.unwrap(value): java.lang.String)
      )(_.marker)
      .build()
  }
  def asReadOnly: zio.aws.iam.model.ListAttachedGroupPoliciesResponse.ReadOnly =
    zio.aws.iam.model.ListAttachedGroupPoliciesResponse.wrap(buildAwsValue())
}
object ListAttachedGroupPoliciesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iam.model.ListAttachedGroupPoliciesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iam.model.ListAttachedGroupPoliciesResponse =
      zio.aws.iam.model.ListAttachedGroupPoliciesResponse(
        attachedPolicies.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        isTruncated.map(value => value),
        marker.map(value => value)
      )
    def attachedPolicies
        : Optional[List[zio.aws.iam.model.AttachedPolicy.ReadOnly]]
    def isTruncated: Optional[BooleanType]
    def marker: Optional[ResponseMarkerType]
    def getAttachedPolicies
        : ZIO[Any, AwsError, List[zio.aws.iam.model.AttachedPolicy.ReadOnly]] =
      AwsError.unwrapOptionField("attachedPolicies", attachedPolicies)
    def getIsTruncated: ZIO[Any, AwsError, BooleanType] =
      AwsError.unwrapOptionField("isTruncated", isTruncated)
    def getMarker: ZIO[Any, AwsError, ResponseMarkerType] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iam.model.ListAttachedGroupPoliciesResponse
  ) extends zio.aws.iam.model.ListAttachedGroupPoliciesResponse.ReadOnly {
    override val attachedPolicies
        : Optional[List[zio.aws.iam.model.AttachedPolicy.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.attachedPolicies())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iam.model.AttachedPolicy.wrap(item)
          }.toList
        )
    override val isTruncated: Optional[BooleanType] = zio.aws.core.internal
      .optionalFromNullable(impl.isTruncated())
      .map(value => zio.aws.iam.model.primitives.BooleanType(value))
    override val marker: Optional[ResponseMarkerType] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => zio.aws.iam.model.primitives.ResponseMarkerType(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iam.model.ListAttachedGroupPoliciesResponse
  ): zio.aws.iam.model.ListAttachedGroupPoliciesResponse.ReadOnly = new Wrapper(
    impl
  )
}
